Examples — joblib 1.3.2 documentation

# Examples

## General examples

General-purpose and introductory examples for joblib.

Checkpoint using joblib.Memory and joblib.Parallel

Checkpoint using joblib.Memory and joblib.Parallel

How to use joblib.Memory

How to use joblib.Memory

Random state within joblib.Parallel

Random state within joblib.Parallel

Serialization of un-picklable objects

Serialization of un-picklable objects

NumPy memmap in joblib.Parallel

NumPy memmap in joblib.Parallel

Improving I/O using compressors

Improving I/O using compressors

Returning a generator in joblib.Parallel

Returning a generator in joblib.Parallel

## Parallel examples

Examples demoing more advanced parallel patterns.

Using Dask for single-machine parallel computing

Using Dask for single-machine parallel computing

Gallery generated by Sphinx-Gallery